diff --git a/htdocs/eventorganization/conferenceorbooth_list.php b/htdocs/eventorganization/conferenceorbooth_list.php
index 520435c9cdc..cf7ffcb607a 100644
--- a/htdocs/eventorganization/conferenceorbooth_list.php
+++ b/htdocs/eventorganization/conferenceorbooth_list.php
@@ -348,8 +348,15 @@ if ($projectid > 0) {
}
print '';
- // Date start - end
- print '
'.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($project->budget_amount, '')) {
+ print ''.price($project->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ('.$langs->trans("Project").') ';
$start = dol_print_date($project->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($project->date_end, 'day');
@@ -360,13 +367,23 @@ if ($projectid > 0) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($project->budget_amount, '')) {
- print price($project->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ // Date start - end of event
+ print ' '.$langs->trans("Dates").' ('.$langs->trans("Event").') ';
+ $start = dol_print_date($project->date_start_event, 'day');
+ print ($start ? $start : '?');
+ $end = dol_print_date($project->date_end_event, 'day');
+ print ' - ';
+ print ($end ? $end : '?');
+ if ($object->hasDelay()) {
+ print img_warning("Late");
}
print ' ';
+ // Location event
+ print ''.$langs->trans("Location").' ';
+ print $project->location;
+ print ' ';
+
// Other attributes
$cols = 2;
$objectconf = $object;
diff --git a/htdocs/install/mysql/migration/16.0.0-17.0.0.sql b/htdocs/install/mysql/migration/16.0.0-17.0.0.sql
index f9eb9968f4f..f796ac441ee 100644
--- a/htdocs/install/mysql/migration/16.0.0-17.0.0.sql
+++ b/htdocs/install/mysql/migration/16.0.0-17.0.0.sql
@@ -196,3 +196,8 @@ ALTER TABLE llx_societe_remise_except ADD COLUMN multicurrency_code varchar(3) N
ALTER TABLE llx_societe_remise_except ADD COLUMN multicurrency_tx double(24,8) NULL;
ALTER TABLE llx_hrm_evaluationdet CHANGE COLUMN rank rankorder integer;
+
+ALTER TABLE llx_projet ADD COLUMN date_start_event datetime;
+ALTER TABLE llx_projet ADD COLUMN date_end_event datetime;
+ALTER TABLE llx_projet ADD COLUMN location varchar(255);
+
diff --git a/htdocs/projet/card.php b/htdocs/projet/card.php
index 17d5c042389..e3a916c0be0 100644
--- a/htdocs/projet/card.php
+++ b/htdocs/projet/card.php
@@ -55,13 +55,15 @@ $dol_openinpopup = GETPOST('dol_openinpopup', 'aZ09');
$status = GETPOST('status', 'int');
$opp_status = GETPOST('opp_status', 'int');
-$opp_percent = price2num(GETPOST('opp_percent', 'alpha'));
-$objcanvas = GETPOST("objcanvas", "alpha");
-$comefromclone = GETPOST("comefromclone", "alpha");
+$opp_percent = price2num(GETPOST('opp_percent', 'alphanohtml'));
+$objcanvas = GETPOST("objcanvas", "alphanohtml");
+$comefromclone = GETPOST("comefromclone", "alphanohtml");
+$date_start = dol_mktime(0, 0, 0, GETPOST('projectstartmonth', 'int'), GETPOST('projectstartday', 'int'), GETPOST('projectstartyear', 'int'));
+$date_end = dol_mktime(0, 0, 0, GETPOST('projectendmonth', 'int'), GETPOST('projectendday', 'int'), GETPOST('projectendyear', 'int'));
+$date_start_event = dol_mktime(0, 0, 0, GETPOST('date_start_eventmonth', 'int'), GETPOST('date_start_eventday', 'int'), GETPOST('date_start_eventyear', 'int'));
+$date_end_event = dol_mktime(0, 0, 0, GETPOST('date_end_eventmonth', 'int'), GETPOST('date_end_eventday', 'int'), GETPOST('date_end_eventyear', 'int'));
+$location = GETPOST('location', 'alphanohtml');
-if ($id == '' && $ref == '' && ($action != "create" && $action != "add" && $action != "update" && !GETPOST("cancel"))) {
- accessforbidden();
-}
$mine = GETPOST('mode') == 'mine' ? 1 : 0;
//if (! $user->rights->projet->all->lire) $mine=1; // Special for projects
@@ -88,14 +90,15 @@ if ($id > 0 || !empty($ref)) {
// fetch optionals attributes and labels
$extrafields->fetch_name_optionals_label($object->table_element);
-$date_start = dol_mktime(0, 0, 0, GETPOST('projectstartmonth', 'int'), GETPOST('projectstartday', 'int'), GETPOST('projectstartyear', 'int'));
-$date_end = dol_mktime(0, 0, 0, GETPOST('projectendmonth', 'int'), GETPOST('projectendday', 'int'), GETPOST('projectendyear', 'int'));
-
// Security check
$socid = GETPOST('socid', 'int');
//if ($user->socid > 0) $socid = $user->socid; // For external user, no check is done on company because readability is managed by public status of project and assignement.
restrictedArea($user, 'projet', $object->id, 'projet&project');
+if ($id == '' && $ref == '' && ($action != "create" && $action != "add" && $action != "update" && !GETPOST("cancel"))) {
+ accessforbidden();
+}
+
$permissiondellink = $user->rights->projet->creer; // Used by the include of actions_dellink.inc.php
@@ -187,6 +190,9 @@ if (empty($reshook)) {
$object->date_c = dol_now();
$object->date_start = $date_start;
$object->date_end = $date_end;
+ $object->date_start_event = $date_start_event;
+ $object->date_end_event = $date_end_event;
+ $object->location = $location;
$object->statut = $status;
$object->opp_status = $opp_status;
$object->opp_percent = $opp_percent;
@@ -281,6 +287,9 @@ if (empty($reshook)) {
$object->public = GETPOST('public', 'alpha');
$object->date_start = (!GETPOST('projectstart')) ? '' : $date_start;
$object->date_end = (!GETPOST('projectend')) ? '' : $date_end;
+ $object->date_start_event = (!GETPOST('date_start_event')) ? '' : $date_start_event;
+ $object->date_end_event = (!GETPOST('date_end_event')) ? '' : $date_end_event;
+ $object->location = $location;
if (GETPOSTISSET('opp_amount')) {
$object->opp_amount = price2num(GETPOST('opp_amount', 'alpha'));
}
@@ -603,6 +612,23 @@ if ($action == 'create' && $user->rights->projet->creer) {
print ' ';
$htmltext = $langs->trans("EventOrganizationDescriptionLong");
print ''.$form->textwithpicto($langs->trans("ManageOrganizeEvent"), $htmltext).' ';
+ print '';
}
print '';
print '';
@@ -673,16 +699,6 @@ if ($action == 'create' && $user->rights->projet->creer) {
}
print '';
- // Date start
- print ''.$langs->trans("DateStart").' ';
- print $form->selectDate(($date_start ? $date_start : ''), 'projectstart', 0, 0, 0, '', 1, 0);
- print ' ';
-
- // Date end
- print ''.$langs->trans("DateEnd").' ';
- print $form->selectDate(($date_end ? $date_end : -1), 'projectend', 0, 0, 0, '', 1, 0);
- print ' ';
-
if (!empty($conf->global->PROJECT_USE_OPPORTUNITIES)) {
// Opportunity status
print ''.$langs->trans("OpportunityStatus").' ';
@@ -708,6 +724,27 @@ if ($action == 'create' && $user->rights->projet->creer) {
print ' ';
print ' ';
+ // Date project
+ print ''.$langs->trans("Date").(isModEnabled('eventorganization') ? ' ('.$langs->trans("Project").') ' : '').' ';
+ print $form->selectDate(($date_start ? $date_start : ''), 'projectstart', 0, 0, 0, '', 1, 0);
+ print ' '.$langs->trans("to").' ';
+ print $form->selectDate(($date_end ? $date_end : -1), 'projectend', 0, 0, 0, '', 1, 0);
+ print ' ';
+
+ if (isModEnabled('eventorganization')) {
+ // Date event
+ print ''.$langs->trans("Date").' ('.$langs->trans("Event").') ';
+ print $form->selectDate(($date_start_event ? $date_start_event : -1), 'date_start_event', 0, 0, 0, '', 1, 0);
+ print ' '.$langs->trans("to").' ';
+ print $form->selectDate(($date_end_event ? $date_end_event : -1), 'date_end_event', 0, 0, 0, '', 1, 0);
+ print ' ';
+
+ // Location
+ print ''.$langs->trans("Location").' ';
+ print ' ';
+ print ' ';
+ }
+
// Description
print ''.$langs->trans("Description").' ';
print '';
@@ -852,11 +889,12 @@ if ($action == 'create' && $user->rights->projet->creer) {
// Status
print ' '.$langs->trans("Status").' ';
- print '';
+ print '';
foreach ($object->statuts_short as $key => $val) {
- print 'statut) == $key ? ' selected="selected"' : '').'>'.$langs->trans($val).' ';
+ print 'statut) == $key ? ' selected="selected"' : '').'>'.$langs->trans($val).' ';
}
print ' ';
+ print ajax_combobox('status');
print ' ';
// Usage
@@ -902,6 +940,21 @@ if ($action == 'create' && $user->rights->projet->creer) {
print ' usage_organize_event ? ' checked="checked"' : '')) . '"> ';
$htmltext = $langs->trans("EventOrganizationDescriptionLong");
print ''.$form->textwithpicto($langs->trans("ManageOrganizeEvent"), $htmltext).' ';
+ print '';
}
print '';
}
@@ -981,9 +1034,18 @@ if ($action == 'create' && $user->rights->projet->creer) {
print '';
}
- // Date start
- print ''.$langs->trans("DateStart").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ print ' ';
+ print $langs->getCurrencySymbol($conf->currency);
+ print ' ';
+ print ' ';
+
+ // Date project
+ print ''.$langs->trans("Date").(isModEnabled('eventorganization') ? ' ('.$langs->trans("Project").') ' : '').' ';
print $form->selectDate($object->date_start ? $object->date_start : -1, 'projectstart', 0, 0, 0, '', 1, 0);
+ print ' '.$langs->trans("to").' ';
+ print $form->selectDate($object->date_end ? $object->date_end : -1, 'projectend', 0, 0, 0, '', 1, 0);
print ' rights->projet->creer) {
print '/>'.$langs->trans("ProjectReportDate").' ';
print ' ';
- // Date end
- print ''.$langs->trans("DateEnd").' ';
- print $form->selectDate($object->date_end ? $object->date_end : -1, 'projectend', 0, 0, 0, '', 1, 0);
- print ' ';
+ if (isModEnabled('eventorganization')) {
+ // Date event
+ print ''.$langs->trans("Date").' ('.$langs->trans("Event").') ';
+ print $form->selectDate(($date_start_event ? $date_start_event : ($object->date_start_event ? $object->date_start_event : -1)), 'date_start_event', 0, 0, 0, '', 1, 0);
+ print ' '.$langs->trans("to").' ';
+ print $form->selectDate(($date_end_event ? $date_end_event : ($object->date_end_event ? $object->date_end_event : -1)), 'date_end_event', 0, 0, 0, '', 1, 0);
+ print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- print ' ';
- print $langs->getCurrencySymbol($conf->currency);
- print ' ';
- print ' ';
+ // Location
+ print ''.$langs->trans("Location").' ';
+ print ' ';
+ print ' ';
+ }
// Description
print ''.$langs->trans("Description").' ';
@@ -1143,18 +1207,6 @@ if ($action == 'create' && $user->rights->projet->creer) {
*/
}
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
- $start = dol_print_date($object->date_start, 'day');
- print ($start ? $start : '?');
- $end = dol_print_date($object->date_end, 'day');
- print ' - ';
- print ($end ? $end : '?');
- if ($object->hasDelay()) {
- print img_warning("Late");
- }
- print ' ';
-
// Budget
print ''.$langs->trans("Budget").' ';
if (strcmp($object->budget_amount, '')) {
@@ -1162,6 +1214,18 @@ if ($action == 'create' && $user->rights->projet->creer) {
}
print ' ';
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
+ $start = dol_print_date($object->date_start, 'day');
+ print ($start ? $start : '?');
+ $end = dol_print_date($object->date_end, 'day');
+ print ' - ';
+ print ($end ? $end : '?');
+ if ($object->hasDelay()) {
+ print img_warning("Late");
+ }
+ print ' ';
+
// Other attributes
$cols = 2;
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/class/project.class.php b/htdocs/projet/class/project.class.php
index 9987f9bc4f0..38bb55b5a24 100644
--- a/htdocs/projet/class/project.class.php
+++ b/htdocs/projet/class/project.class.php
@@ -87,29 +87,44 @@ class Project extends CommonObject
public $title;
/**
- * @var int Date start
+ * @var int Date start
* @deprecated
* @see $date_start
*/
public $dateo;
/**
- * @var int Date start
+ * @var int Date start
*/
public $date_start;
/**
- * @var int Date end
+ * @var int Date end
* @deprecated
* @see $date_end
*/
public $datee;
/**
- * @var int Date end
+ * @var int Date end
*/
public $date_end;
+ /**
+ * @var int Date start event
+ */
+ public $date_start_event;
+
+ /**
+ * @var int Date end event
+ */
+ public $date_end_event;
+
+ /**
+ * @var string Location
+ */
+ public $location;
+
/**
* @var int Date close
*/
@@ -264,30 +279,35 @@ class Project extends CommonObject
'datee' =>array('type'=>'date', 'label'=>'DateEnd', 'enabled'=>1, 'visible'=>1, 'position'=>35),
'description' =>array('type'=>'text', 'label'=>'Description', 'enabled'=>1, 'visible'=>3, 'position'=>55, 'searchall'=>1),
'public' =>array('type'=>'integer', 'label'=>'Visibility', 'enabled'=>1, 'visible'=>1, 'position'=>65),
- 'fk_opp_status' =>array('type'=>'integer', 'label'=>'OpportunityStatusShort', 'enabled'=>'!empty($conf->global->PROJECT_USE_OPPORTUNITIES)', 'visible'=>1, 'position'=>75),
- 'opp_percent' =>array('type'=>'double(5,2)', 'label'=>'OpportunityProbabilityShort', 'enabled'=>'!empty($conf->global->PROJECT_USE_OPPORTUNITIES)', 'visible'=>1, 'position'=>80),
+ 'fk_opp_status' =>array('type'=>'integer', 'label'=>'OpportunityStatusShort', 'enabled'=>'getDolGlobalString("PROJECT_USE_OPPORTUNITIES")', 'visible'=>1, 'position'=>75),
+ 'opp_percent' =>array('type'=>'double(5,2)', 'label'=>'OpportunityProbabilityShort', 'enabled'=>'getDolGlobalString("PROJECT_USE_OPPORTUNITIES")', 'visible'=>1, 'position'=>80),
'note_private' =>array('type'=>'text', 'label'=>'NotePrivate', 'enabled'=>1, 'visible'=>0, 'position'=>85, 'searchall'=>1),
'note_public' =>array('type'=>'text', 'label'=>'NotePublic', 'enabled'=>1, 'visible'=>0, 'position'=>90, 'searchall'=>1),
'model_pdf' =>array('type'=>'varchar(255)', 'label'=>'ModelPdf', 'enabled'=>1, 'visible'=>0, 'position'=>95),
'date_close' =>array('type'=>'datetime', 'label'=>'DateClosing', 'enabled'=>1, 'visible'=>0, 'position'=>105),
'fk_user_close' =>array('type'=>'integer', 'label'=>'UserClosing', 'enabled'=>1, 'visible'=>0, 'position'=>110),
- 'opp_amount' =>array('type'=>'double(24,8)', 'label'=>'OpportunityAmountShort', 'enabled'=>1, 'visible'=>'!empty($conf->global->PROJECT_USE_OPPORTUNITIES)', 'position'=>115),
+ 'opp_amount' =>array('type'=>'double(24,8)', 'label'=>'OpportunityAmountShort', 'enabled'=>1, 'visible'=>'getDolGlobalString("PROJECT_USE_OPPORTUNITIES")', 'position'=>115),
'budget_amount' =>array('type'=>'double(24,8)', 'label'=>'Budget', 'enabled'=>1, 'visible'=>1, 'position'=>119),
'usage_bill_time' =>array('type'=>'integer', 'label'=>'UsageBillTimeShort', 'enabled'=>1, 'visible'=>-1, 'position'=>130),
'usage_opportunity' =>array('type'=>'integer', 'label'=>'UsageOpportunity', 'enabled'=>1, 'visible'=>-1, 'position'=>135),
'usage_task' =>array('type'=>'integer', 'label'=>'UsageTasks', 'enabled'=>1, 'visible'=>-1, 'position'=>140),
'usage_organize_event' =>array('type'=>'integer', 'label'=>'UsageOrganizeEvent', 'enabled'=>1, 'visible'=>-1, 'position'=>145),
- 'accept_conference_suggestions' =>array('type'=>'integer', 'label'=>'AllowUnknownPeopleSuggestConf', 'enabled'=>1, 'visible'=>-1, 'position'=>146),
- 'accept_booth_suggestions' =>array('type'=>'integer', 'label'=>'AllowUnknownPeopleSuggestBooth', 'enabled'=>1, 'visible'=>-1, 'position'=>147),
- 'price_registration' =>array('type'=>'double(24,8)', 'label'=>'PriceOfRegistration', 'enabled'=>1, 'visible'=>-1, 'position'=>148),
- 'price_booth' =>array('type'=>'double(24,8)', 'label'=>'PriceOfBooth', 'enabled'=>1, 'visible'=>-1, 'position'=>149),
- 'max_attendees' =>array('type'=>'integer', 'label'=>'MaxNbOfAttendees', 'enabled'=>1, 'visible'=>-1, 'position'=>150),
- 'datec' =>array('type'=>'datetime', 'label'=>'DateCreationShort', 'enabled'=>1, 'visible'=>-2, 'position'=>200),
- 'tms' =>array('type'=>'timestamp', 'label'=>'DateModificationShort', 'enabled'=>1, 'visible'=>-2, 'notnull'=>1, 'position'=>205),
- 'fk_user_creat' =>array('type'=>'integer', 'label'=>'UserCreation', 'enabled'=>1, 'visible'=>0, 'notnull'=>1, 'position'=>210),
- 'fk_user_modif' =>array('type'=>'integer', 'label'=>'UserModification', 'enabled'=>1, 'visible'=>0, 'position'=>215),
- 'import_key' =>array('type'=>'varchar(14)', 'label'=>'ImportId', 'enabled'=>1, 'visible'=>0, 'position'=>220),
- 'email_msgid'=>array('type'=>'varchar(255)', 'label'=>'EmailMsgID', 'enabled'=>1, 'visible'=>-1, 'position'=>250, 'help'=>'EmailMsgIDWhenSourceisEmail'),
+ // Properties for event organization
+ 'date_start_event' =>array('type'=>'date', 'label'=>'DateStartEvent', 'enabled'=>1, 'visible'=>1, 'position'=>200),
+ 'date_end_event' =>array('type'=>'date', 'label'=>'DateEndEvent', 'enabled'=>1, 'visible'=>1, 'position'=>201),
+ 'location' =>array('type'=>'text', 'label'=>'Location', 'enabled'=>1, 'visible'=>3, 'position'=>55, 'searchall'=>202),
+ 'accept_conference_suggestions' =>array('type'=>'integer', 'label'=>'AllowUnknownPeopleSuggestConf', 'enabled'=>1, 'visible'=>-1, 'position'=>210),
+ 'accept_booth_suggestions' =>array('type'=>'integer', 'label'=>'AllowUnknownPeopleSuggestBooth', 'enabled'=>1, 'visible'=>-1, 'position'=>211),
+ 'price_registration' =>array('type'=>'double(24,8)', 'label'=>'PriceOfRegistration', 'enabled'=>1, 'visible'=>-1, 'position'=>212),
+ 'price_booth' =>array('type'=>'double(24,8)', 'label'=>'PriceOfBooth', 'enabled'=>1, 'visible'=>-1, 'position'=>215),
+ 'max_attendees' =>array('type'=>'integer', 'label'=>'MaxNbOfAttendees', 'enabled'=>1, 'visible'=>-1, 'position'=>215),
+ // Generic
+ 'datec' =>array('type'=>'datetime', 'label'=>'DateCreationShort', 'enabled'=>1, 'visible'=>-2, 'position'=>400),
+ 'tms' =>array('type'=>'timestamp', 'label'=>'DateModificationShort', 'enabled'=>1, 'visible'=>-2, 'notnull'=>1, 'position'=>405),
+ 'fk_user_creat' =>array('type'=>'integer', 'label'=>'UserCreation', 'enabled'=>1, 'visible'=>0, 'notnull'=>1, 'position'=>410),
+ 'fk_user_modif' =>array('type'=>'integer', 'label'=>'UserModification', 'enabled'=>1, 'visible'=>0, 'position'=>415),
+ 'import_key' =>array('type'=>'varchar(14)', 'label'=>'ImportId', 'enabled'=>1, 'visible'=>0, 'position'=>420),
+ 'email_msgid'=>array('type'=>'varchar(255)', 'label'=>'EmailMsgID', 'enabled'=>1, 'visible'=>-1, 'position'=>450, 'help'=>'EmailMsgIDWhenSourceisEmail'),
'fk_statut' =>array('type'=>'smallint(6)', 'label'=>'Status', 'enabled'=>1, 'visible'=>1, 'notnull'=>1, 'position'=>500)
);
// END MODULEBUILDER PROPERTIES
@@ -408,6 +428,9 @@ class Project extends CommonObject
$sql .= ", price_registration";
$sql .= ", price_booth";
$sql .= ", max_attendees";
+ $sql .= ", date_start_event";
+ $sql .= ", date_end_event";
+ $sql .= ", location";
$sql .= ", email_msgid";
$sql .= ", note_private";
$sql .= ", note_public";
@@ -436,6 +459,9 @@ class Project extends CommonObject
$sql .= ", ".(strcmp($this->price_registration, '') ? price2num($this->price_registration) : 'null');
$sql .= ", ".(strcmp($this->price_booth, '') ? price2num($this->price_booth) : 'null');
$sql .= ", ".(strcmp($this->max_attendees, '') ? ((int) $this->max_attendees) : 'null');
+ $sql .= ", ".($this->date_start_event != '' ? "'".$this->db->idate($this->date_start_event)."'" : 'null');
+ $sql .= ", ".($this->date_end_event != '' ? "'".$this->db->idate($this->date_end_event)."'" : 'null');
+ $sql .= ", ".($this->location ? "'".$this->db->escape($this->location)."'" : 'null');
$sql .= ", ".($this->email_msgid ? "'".$this->db->escape($this->email_msgid)."'" : 'null');
$sql .= ", ".($this->note_private ? "'".$this->db->escape($this->note_private)."'" : 'null');
$sql .= ", ".($this->note_public ? "'".$this->db->escape($this->note_public)."'" : 'null');
@@ -530,11 +556,11 @@ class Project extends CommonObject
$sql .= ", fk_opp_status = ".((is_numeric($this->opp_status) && $this->opp_status > 0) ? $this->opp_status : 'null');
$sql .= ", opp_percent = ".((is_numeric($this->opp_percent) && $this->opp_percent != '') ? $this->opp_percent : 'null');
$sql .= ", public = ".($this->public ? 1 : 0);
- $sql .= ", datec=".($this->date_c != '' ? "'".$this->db->idate($this->date_c)."'" : 'null');
- $sql .= ", dateo=".($this->date_start != '' ? "'".$this->db->idate($this->date_start)."'" : 'null');
- $sql .= ", datee=".($this->date_end != '' ? "'".$this->db->idate($this->date_end)."'" : 'null');
- $sql .= ", date_close=".($this->date_close != '' ? "'".$this->db->idate($this->date_close)."'" : 'null');
- $sql .= ", fk_user_close=".($this->fk_user_close > 0 ? $this->fk_user_close : "null");
+ $sql .= ", datec = ".($this->date_c != '' ? "'".$this->db->idate($this->date_c)."'" : 'null');
+ $sql .= ", dateo = ".($this->date_start != '' ? "'".$this->db->idate($this->date_start)."'" : 'null');
+ $sql .= ", datee = ".($this->date_end != '' ? "'".$this->db->idate($this->date_end)."'" : 'null');
+ $sql .= ", date_close = ".($this->date_close != '' ? "'".$this->db->idate($this->date_close)."'" : 'null');
+ $sql .= ", fk_user_close = ".($this->fk_user_close > 0 ? $this->fk_user_close : "null");
$sql .= ", opp_amount = ".(strcmp($this->opp_amount, '') ? price2num($this->opp_amount) : "null");
$sql .= ", budget_amount = ".(strcmp($this->budget_amount, '') ? price2num($this->budget_amount) : "null");
$sql .= ", fk_user_modif = ".$user->id;
@@ -547,6 +573,9 @@ class Project extends CommonObject
$sql .= ", price_registration = ".(strcmp($this->price_registration, '') ? price2num($this->price_registration) : "null");
$sql .= ", price_booth = ".(strcmp($this->price_booth, '') ? price2num($this->price_booth) : "null");
$sql .= ", max_attendees = ".(strcmp($this->max_attendees, '') ? price2num($this->max_attendees) : "null");
+ $sql .= ", date_start_event = ".($this->date_start_event != '' ? "'".$this->db->idate($this->date_start_event)."'" : 'null');
+ $sql .= ", date_end_event = ".($this->date_end_event != '' ? "'".$this->db->idate($this->date_end_event)."'" : 'null');
+ $sql .= ", location = '".$this->db->escape($this->location)."'";
$sql .= ", entity = ".((int) $this->entity);
$sql .= " WHERE rowid = ".((int) $this->id);
@@ -631,9 +660,9 @@ class Project extends CommonObject
}
$sql = "SELECT rowid, entity, ref, title, description, public, datec, opp_amount, budget_amount,";
- $sql .= " tms, dateo, datee, date_close, fk_soc, fk_user_creat, fk_user_modif, fk_user_close, fk_statut as status, fk_opp_status, opp_percent,";
+ $sql .= " tms, dateo as date_start, datee as date_end, date_close, fk_soc, fk_user_creat, fk_user_modif, fk_user_close, fk_statut as status, fk_opp_status, opp_percent,";
$sql .= " note_private, note_public, model_pdf, usage_opportunity, usage_task, usage_bill_time, usage_organize_event, email_msgid,";
- $sql .= " accept_conference_suggestions, accept_booth_suggestions, price_registration, price_booth, max_attendees";
+ $sql .= " accept_conference_suggestions, accept_booth_suggestions, price_registration, price_booth, max_attendees, date_start_event, date_end_event, location";
$sql .= " FROM ".MAIN_DB_PREFIX."projet";
if (!empty($id)) {
$sql .= " WHERE rowid = ".((int) $id);
@@ -665,8 +694,8 @@ class Project extends CommonObject
$this->datec = $this->db->jdate($obj->datec); // TODO deprecated
$this->date_m = $this->db->jdate($obj->tms);
$this->datem = $this->db->jdate($obj->tms); // TODO deprecated
- $this->date_start = $this->db->jdate($obj->dateo);
- $this->date_end = $this->db->jdate($obj->datee);
+ $this->date_start = $this->db->jdate($obj->date_start);
+ $this->date_end = $this->db->jdate($obj->date_end);
$this->date_close = $this->db->jdate($obj->date_close);
$this->note_private = $obj->note_private;
$this->note_public = $obj->note_public;
@@ -692,6 +721,9 @@ class Project extends CommonObject
$this->price_registration = $obj->price_registration;
$this->price_booth = $obj->price_booth;
$this->max_attendees = $obj->max_attendees;
+ $this->date_start_event = $this->db->jdate($obj->date_start_event);
+ $this->date_end_event = $this->db->jdate($obj->date_end_event);
+ $this->location = $obj->location;
$this->email_msgid = $obj->email_msgid;
$this->db->free($resql);
diff --git a/htdocs/projet/comment.php b/htdocs/projet/comment.php
index 5ea5b920f8c..872aab6046c 100644
--- a/htdocs/projet/comment.php
+++ b/htdocs/projet/comment.php
@@ -134,15 +134,6 @@ if ($object->public) {
}
print '';
-// Date start - end
-print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
-print dol_print_date($object->date_start, 'day');
-$end = dol_print_date($object->date_end, 'day');
-if ($end) {
- print ' - '.$end;
-}
-print ' ';
-
// Budget
print ''.$langs->trans("Budget").' ';
if (strcmp($object->budget_amount, '')) {
@@ -150,6 +141,15 @@ if (strcmp($object->budget_amount, '')) {
}
print ' ';
+// Date start - end project
+print ''.$langs->trans("Dates").' ';
+print dol_print_date($object->date_start, 'day');
+$end = dol_print_date($object->date_end, 'day');
+if ($end) {
+ print ' - '.$end;
+}
+print ' ';
+
// Other attributes
$cols = 2;
// include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/contact.php b/htdocs/projet/contact.php
index ee37aa68fdd..3e2e85a3757 100644
--- a/htdocs/projet/contact.php
+++ b/htdocs/projet/contact.php
@@ -385,8 +385,15 @@ if ($id > 0 || !empty($ref)) {
print '';
}
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($object->budget_amount, '')) {
+ print ''.price($object->budget_amount, '', $langs, 0, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($object->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($object->date_end, 'day');
@@ -397,13 +404,6 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($object->budget_amount, '')) {
- print ''.price($object->budget_amount, '', $langs, 0, 0, 0, $conf->currency).' ';
- }
- print ' ';
-
// Other attributes
$cols = 2;
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/element.php b/htdocs/projet/element.php
index 346382c6294..7bf40647783 100644
--- a/htdocs/projet/element.php
+++ b/htdocs/projet/element.php
@@ -307,8 +307,15 @@ if (!empty($conf->global->PROJECT_USE_OPPORTUNITIES)) {
print '';
}
-// Date start - end
-print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+// Budget
+print ' '.$langs->trans("Budget").' ';
+if (strcmp($object->budget_amount, '')) {
+ print ''.price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+}
+print ' ';
+
+// Date start - end project
+print ''.$langs->trans("Dates").' ';
$start = dol_print_date($object->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($object->date_end, 'day');
@@ -319,13 +326,6 @@ if ($object->hasDelay()) {
}
print ' ';
-// Budget
-print ''.$langs->trans("Budget").' ';
-if (strcmp($object->budget_amount, '')) {
- print ''.price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
-}
-print ' ';
-
// Other attributes
$cols = 2;
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/ganttview.php b/htdocs/projet/ganttview.php
index c5549429edb..c04614c859e 100644
--- a/htdocs/projet/ganttview.php
+++ b/htdocs/projet/ganttview.php
@@ -179,8 +179,15 @@ if (($id > 0 && is_numeric($id)) || !empty($ref)) {
}
print '';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($object->budget_amount, '')) {
+ print price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($object->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($object->date_end, 'day');
@@ -191,13 +198,6 @@ if (($id > 0 && is_numeric($id)) || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($object->budget_amount, '')) {
- print price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
- }
- print ' ';
-
// Other attributes
$cols = 2;
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/list.php b/htdocs/projet/list.php
index 9ca5fc63c76..696888a75dd 100644
--- a/htdocs/projet/list.php
+++ b/htdocs/projet/list.php
@@ -1355,7 +1355,8 @@ while ($i < $imaxinloop) {
$totalarray['nbfield']++;
}
}
- // Date start
+
+ // Date start project
if (!empty($arrayfields['p.dateo']['checked'])) {
print '';
print dol_print_date($db->jdate($obj->date_start), 'day');
@@ -1364,7 +1365,7 @@ while ($i < $imaxinloop) {
$totalarray['nbfield']++;
}
}
- // Date end
+ // Date end project
if (!empty($arrayfields['p.datee']['checked'])) {
print ' ';
print dol_print_date($db->jdate($obj->date_end), 'day');
@@ -1373,6 +1374,7 @@ while ($i < $imaxinloop) {
$totalarray['nbfield']++;
}
}
+
// Visibility
if (!empty($arrayfields['p.public']['checked'])) {
print ' ';
diff --git a/htdocs/projet/tasks.php b/htdocs/projet/tasks.php
index 73d3c238026..f957b59b3c2 100644
--- a/htdocs/projet/tasks.php
+++ b/htdocs/projet/tasks.php
@@ -614,8 +614,15 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($object->budget_amount, '')) {
+ print ''.price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($object->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($object->date_end, 'day');
@@ -626,13 +633,6 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($object->budget_amount, '')) {
- print ''.price($object->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
- }
- print ' ';
-
// Other attributes
$cols = 2;
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';
@@ -750,12 +750,12 @@ if ($action == 'create' && $user->rights->projet->creer && (empty($object->third
}
print '';
- // Date start
+ // Date start task
print ''.$langs->trans("DateStart").' ';
print $form->selectDate((!empty($date_start) ? $date_start : ''), 'dateo', 1, 1, 0, '', 1, 1);
print ' ';
- // Date end
+ // Date end task
print ''.$langs->trans("DateEnd").' ';
print $form->selectDate((!empty($date_end) ? $date_end : -1), 'datee', -1, 1, 0, '', 1, 1);
print ' ';
diff --git a/htdocs/projet/tasks/comment.php b/htdocs/projet/tasks/comment.php
index 1f5628bb050..e6749612f46 100644
--- a/htdocs/projet/tasks/comment.php
+++ b/htdocs/projet/tasks/comment.php
@@ -221,8 +221,15 @@ if ($id > 0 || !empty($ref)) {
print '';
}
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -233,13 +240,6 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
- }
- print ' ';
-
// Other attributes
$cols = 2;
//include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/tasks/contact.php b/htdocs/projet/tasks/contact.php
index 14a87b375e8..4427af86f52 100644
--- a/htdocs/projet/tasks/contact.php
+++ b/htdocs/projet/tasks/contact.php
@@ -257,8 +257,15 @@ if ($id > 0 || !empty($ref)) {
}
print '';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -269,13 +276,6 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
- }
- print ' ';
-
// Other attributes
$cols = 2;
//include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/tasks/document.php b/htdocs/projet/tasks/document.php
index 3e569cd557f..fb89ba372e7 100644
--- a/htdocs/projet/tasks/document.php
+++ b/htdocs/projet/tasks/document.php
@@ -214,8 +214,15 @@ if ($object->id > 0) {
}
print '';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -226,13 +233,6 @@ if ($object->id > 0) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
- }
- print ' ';
-
// Other attributes
$cols = 2;
//include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/tasks/list.php b/htdocs/projet/tasks/list.php
index 1f0130bd7b4..76261480ffe 100644
--- a/htdocs/projet/tasks/list.php
+++ b/htdocs/projet/tasks/list.php
@@ -1117,7 +1117,8 @@ while ($i < $imaxinloop) {
$totalarray['nbfield']++;
}
}
- // Date start
+
+ // Date start project
if (!empty($arrayfields['t.dateo']['checked'])) {
print '';
print dol_print_date($db->jdate($obj->date_start), 'day');
@@ -1126,7 +1127,7 @@ while ($i < $imaxinloop) {
$totalarray['nbfield']++;
}
}
- // Date end
+ // Date end project
if (!empty($arrayfields['t.datee']['checked'])) {
print ' ';
print dol_print_date($db->jdate($obj->date_end), 'day');
diff --git a/htdocs/projet/tasks/note.php b/htdocs/projet/tasks/note.php
index 40f8f636e72..7c02dad5785 100644
--- a/htdocs/projet/tasks/note.php
+++ b/htdocs/projet/tasks/note.php
@@ -203,8 +203,15 @@ if ($object->id > 0) {
}
print ' ';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -215,13 +222,6 @@ if ($object->id > 0) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
- }
- print ' ';
-
// Other attributes
$cols = 2;
//include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
diff --git a/htdocs/projet/tasks/task.php b/htdocs/projet/tasks/task.php
index 77cd9f09c9e..95c755097eb 100644
--- a/htdocs/projet/tasks/task.php
+++ b/htdocs/projet/tasks/task.php
@@ -325,8 +325,15 @@ if ($id > 0 || !empty($ref)) {
}
print '';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print ''.price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -337,13 +344,6 @@ if ($id > 0 || !empty($ref)) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print ''.price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
- }
- print ' ';
-
// Other attributes
$cols = 2;
//include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
@@ -578,7 +578,7 @@ if ($id > 0 || !empty($ref)) {
}
print '';
- // Date start - Date end
+ // Date start - Date end task
print ''.$langs->trans("DateStart").' - '.$langs->trans("Deadline").' ';
$start = dol_print_date($object->date_start, 'dayhour');
print ($start ? $start : '?');
diff --git a/htdocs/projet/tasks/time.php b/htdocs/projet/tasks/time.php
index 00d45eedea7..d268a72b12d 100644
--- a/htdocs/projet/tasks/time.php
+++ b/htdocs/projet/tasks/time.php
@@ -967,8 +967,15 @@ if (($id > 0 || !empty($ref)) || $projectidforalltimes > 0 || $allprojectforuser
}
print ' ';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print ''.price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -979,16 +986,12 @@ if (($id > 0 || !empty($ref)) || $projectidforalltimes > 0 || $allprojectforuser
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print ''.price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
- }
- print ' ';
-
// Other attributes
$cols = 2;
- //include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
+ $savobject = $object;
+ $object = $projectstatic;
+ include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
+ $object = $savobject;
print '';
@@ -1127,7 +1130,7 @@ if (($id > 0 || !empty($ref)) || $projectidforalltimes > 0 || $allprojectforuser
}
print '';
- // Date start - Date end
+ // Date start - Date end task
print ''.$langs->trans("DateStart").' - '.$langs->trans("Deadline").' ';
$start = dol_print_date($object->date_start, 'dayhour');
print ($start ? $start : '?');
diff --git a/htdocs/public/eventorganization/attendee_new.php b/htdocs/public/eventorganization/attendee_new.php
index 589bf2c8dac..995b5f7a44c 100644
--- a/htdocs/public/eventorganization/attendee_new.php
+++ b/htdocs/public/eventorganization/attendee_new.php
@@ -646,7 +646,7 @@ print '';
// Welcome message
-print $langs->trans("EvntOrgWelcomeMessage", $project->title . ' '. $conference->label);
+print '
'.$langs->trans("EvntOrgWelcomeMessage", $project->title . ' '. $conference->label).' ';
print '
';
$maxattendees = 0;
if ($conference->id) {
@@ -691,8 +691,8 @@ if ((!empty($conference->id) && $conference->status == ConferenceOrBooth::STATUS
print '
';
print '
';
-
- print '
' . $langs->trans("FieldsWithAreMandatory", '*') . ' ';
+ print '
';
+ //print '
' . $langs->trans("FieldsWithAreMandatory", '*') . ' ';
//print $langs->trans("FieldsWithIsForPublic",'**').'
';
print dol_get_fiche_head('');
@@ -711,18 +711,22 @@ if ((!empty($conference->id) && $conference->status == ConferenceOrBooth::STATUS
print '
diff --git a/htdocs/eventorganization/conferenceorboothattendee_list.php b/htdocs/eventorganization/conferenceorboothattendee_list.php
index 167a79959f5..dccad6b9583 100644
--- a/htdocs/eventorganization/conferenceorboothattendee_list.php
+++ b/htdocs/eventorganization/conferenceorboothattendee_list.php
@@ -474,8 +474,15 @@ if ($projectstatic->id > 0 || $confOrBooth > 0) {
}
print '';
- // Date start - end
- print ''.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").' ';
+ // Budget
+ print ' '.$langs->trans("Budget").' ';
+ if (strcmp($projectstatic->budget_amount, '')) {
+ print ''.price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency).' ';
+ }
+ print ' ';
+
+ // Date start - end project
+ print ''.$langs->trans("Dates").' ('.$langs->trans("Project").') ';
$start = dol_print_date($projectstatic->date_start, 'day');
print ($start ? $start : '?');
$end = dol_print_date($projectstatic->date_end, 'day');
@@ -486,13 +493,23 @@ if ($projectstatic->id > 0 || $confOrBooth > 0) {
}
print ' ';
- // Budget
- print ''.$langs->trans("Budget").' ';
- if (strcmp($projectstatic->budget_amount, '')) {
- print price($projectstatic->budget_amount, '', $langs, 1, 0, 0, $conf->currency);
+ // Date start - end of event
+ print ' '.$langs->trans("Dates").' ('.$langs->trans("Event").') ';
+ $start = dol_print_date($projectstatic->date_start_event, 'day');
+ print ($start ? $start : '?');
+ $end = dol_print_date($projectstatic->date_end_event, 'day');
+ print ' - ';
+ print ($end ? $end : '?');
+ if ($projectstatic->hasDelay()) {
+ print img_warning("Late");
}
print ' ';
+ // Location event
+ print ''.$langs->trans("Location").' ';
+ print $projectstatic->location;
+ print ' ';
+
// Other attributes
$cols = 2;
$objectconf = $object;
diff --git a/htdocs/install/mysql/tables/llx_projet.sql b/htdocs/install/mysql/tables/llx_projet.sql
index 197a92ac2be..5b3df54ba14 100644
--- a/htdocs/install/mysql/tables/llx_projet.sql
+++ b/htdocs/install/mysql/tables/llx_projet.sql
@@ -47,7 +47,10 @@ create table llx_projet
usage_opportunity integer DEFAULT 0, -- Set to 1 if project is used to follow an opportunity
usage_task integer DEFAULT 1, -- Set to 1 if project is used to manage tasks and/or record timesheet
usage_bill_time integer DEFAULT 0, -- Set to 1 if time spent must be converted into invoices
- usage_organize_event integer DEFAULT 0, -- Set to 1 if you want to use project to organize an event or receive attendees registration
+ usage_organize_event integer DEFAULT 0, -- Set to 1 if you want to use project to organize an event or receive attendees registration
+ date_start_event datetime, -- date start event
+ date_end_event datetime, -- date end event
+ location varchar(255), -- location
accept_conference_suggestions integer DEFAULT 0, -- Set to 1 if you want to allow unknown people to suggest conferences
accept_booth_suggestions integer DEFAULT 0, -- Set to 1 if you want to Allow unknown people to suggest booth
max_attendees integer DEFAULT 0,